@@ -1,13 +1,13 @@
 package Perl::Critic::Config;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
 use English qw(-no_match_vars);
 use Readonly;
 
-use List::MoreUtils qw(any none apply);
+use List::SomeUtils qw( any apply );
 use Scalar::Util qw(blessed);
 
 use Perl::Critic::Exception::AggregateConfiguration;
@@ -25,11 +25,10 @@ use Perl::Critic::Utils::Constants qw<
     :profile_strictness
     $_MODULE_VERSION_TERM_ANSICOLOR
 >;
-use Perl::Critic::Utils::DataConversion qw< boolean_to_number dor >;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '1.138';
+our $VERSION = '1.152';
 
 #-----------------------------------------------------------------------------
 
@@ -112,17 +111,14 @@ sub _init {
         $args{'-program-extensions'}, $errors);
 
     # If given, these options can be true or false (but defined)
-    # We normalize these to numeric values by multiplying them by 1;
-    $self->{_force} = boolean_to_number( dor( $args{-force}, $options_processor->force() ) );
-    $self->{_only}  = boolean_to_number( dor( $args{-only},  $options_processor->only()  ) );
-    $self->{_color} = boolean_to_number( dor( $args{-color}, $options_processor->color() ) );
+    $self->{_force} = _boolean_to_number( $args{-force} // $options_processor->force() );
+    $self->{_only}  = _boolean_to_number( $args{-only}  // $options_processor->only()  );
+    $self->{_color} = _boolean_to_number( $args{-color} // $options_processor->color() );
     $self->{_unsafe_allowed} =
-        boolean_to_number(
-            dor( $args{'-allow-unsafe'}, $options_processor->allow_unsafe()
-        ) );
+        _boolean_to_number( $args{'-allow-unsafe'} // $options_processor->allow_unsafe() );
     $self->{_criticism_fatal} =
-        boolean_to_number(
-            dor( $args{'-criticism-fatal'}, $options_processor->criticism_fatal() )
+        _boolean_to_number(
+            $args{'-criticism-fatal'} // $options_processor->criticism_fatal()
         );
 
 
@@ -154,6 +150,12 @@ sub _init {
 
 #-----------------------------------------------------------------------------
 
+sub _boolean_to_number {  ## no critic (RequireArgUnpacking)
+    return $_[0] ? $TRUE : $FALSE;
+}
+
+#-----------------------------------------------------------------------------
+
 sub add_policy {
 
     my ( $self, %args ) = @_;
@@ -668,7 +670,7 @@ sub _validate_and_save_pager {
 
     my $pager;
     if ( $args_value ) {
-        $pager = defined $args_value ? $args_value : $EMPTY;
+        $pager = $args_value;
     }
     elsif ( $ENV{PERLCRITIC_PAGER} ) {
         $pager = $ENV{PERLCRITIC_PAGER};
@@ -767,7 +769,7 @@ sub _validate_and_save_program_extensions {
 }
 
 #-----------------------------------------------------------------------------
-# Begin ACCESSSOR methods
+# Begin ACCESSOR methods
 
 sub _profile {
     my ($self) = @_;
@@ -1265,7 +1267,7 @@ A simple configuration might look like this:
     [Modules::RequireFilenameMatchesPackage]
     add_themes = larry
 
-    [TestingAndDebugging::RequireTestLables]
+    [TestingAndDebugging::RequireTestLabels]
     add_themes = curly moe
 
     #--------------------------------------------------------------
@@ -1312,7 +1314,7 @@ needs.
     bugs              Policies that prevent or reveal bugs
     maintenance       Policies that affect the long-term health of the code
     cosmetic          Policies that only have a superficial effect
-    complexity        Policies that specificaly relate to code complexity
+    complexity        Policies that specifically relate to code complexity
     security          Policies that relate to security issues
     tests             Policies that are specific to test programs
 
@@ -1373,7 +1375,7 @@ Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
+Copyright (c) 2005-2023 Imaginative Software Systems
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
