@@ -1,27 +1,36 @@
 package Perl::Critic::Policy::Subroutines::ProhibitBuiltinHomonyms;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities :data_conversion
-                            :classification :characters };
+                            :classification :characters $EMPTY };
 
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.126';
+our $VERSION = '1.152';
 
 #-----------------------------------------------------------------------------
 
-Readonly::Array my @ALLOW => qw( import AUTOLOAD DESTROY );
+Readonly::Array my @ALLOW => qw( import unimport AUTOLOAD DESTROY );
 Readonly::Hash my %ALLOW => hashify( @ALLOW );
 Readonly::Scalar my $DESC  => q{Subroutine name is a homonym for builtin %s %s};
 Readonly::Scalar my $EXPL  => [177];
 
 #-----------------------------------------------------------------------------
 
-sub supported_parameters { return ()                    }
+sub supported_parameters {
+    return (
+        {
+            name           => 'allow',
+            description    => q<Subroutines matching the name regex to allow under this policy.>,
+            default_string => $EMPTY,
+            behavior       => 'string list',
+        },
+    );
+}
 sub default_severity     { return $SEVERITY_HIGH        }
 sub default_themes       { return qw( core bugs pbp certrule )   }
 sub applies_to           { return 'PPI::Statement::Sub' }
@@ -31,7 +40,8 @@ sub applies_to           { return 'PPI::Statement::Sub' }
 sub violates {
     my ( $self, $elem, undef ) = @_;
     return if $elem->isa('PPI::Statement::Scheduled'); #e.g. BEGIN, INIT, END
-    return if exists $ALLOW{ $elem->name() };
+    return if exists $ALLOW{ $elem->name() } and not defined $elem->type();
+    return if exists $self->{_allow}{ $elem->name() };
 
     my $homonym_type = $EMPTY;
     if ( is_perl_builtin( $elem ) ) {
@@ -89,7 +99,14 @@ as well as C<AUTOLOAD>, C<DESTROY>, and C<import> subroutines.
 
 =head1 CONFIGURATION
 
-This Policy is not configurable except for the standard options.
+You can configure additional builtin homonyms to accept by specifying them
+in a space-delimited list to the C<allow> option:
+
+    [Subroutines::ProhibitBuiltinHomonyms]
+    allow = default index
+
+These are added to the default list of exemptions from this policy. So the
+above allows C<< sub default {} >> and C<< sub index {} >>.
 
 
 =head1 CAVEATS
@@ -105,7 +122,7 @@ Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
+Copyright (c) 2005-2022 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
