@@ -1,26 +1,19 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitEscapedCharacters.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitEscapedCharacters;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities };
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.152';
 
 #-----------------------------------------------------------------------------
 
 Readonly::Scalar my $DESC     => q{Numeric escapes in interpolated string};
-Readonly::Scalar my $EXPL     => [ 56 ];
+Readonly::Scalar my $EXPL     => [ 54..55 ];
 
 #-----------------------------------------------------------------------------
 
@@ -79,16 +72,13 @@ values.  The syntax is less compact, but dramatically more readable.
 This Policy is not configurable except for the standard options.
 
 
-=head1 SEE ALSO
-
-
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Chris Dolan.  All rights reserved.
+Copyright (c) 2006-2011 Chris Dolan.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
