@@ -1,23 +1,14 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/PolicyListing.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::PolicyListing;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
-use English qw(-no_match_vars);
-
 use Perl::Critic::Policy qw();
 
 use overload ( q<""> => 'to_string' );
 
-our $VERSION = '1.092';
+our $VERSION = '1.152';
 
 #-----------------------------------------------------------------------------
 
@@ -63,9 +54,15 @@ This is a helper class that formats a set of Policy objects for
 pretty-printing.  There are no user-serviceable parts here.
 
 
+=head1 INTERFACE SUPPORT
+
+This is considered to be a non-public class.  Its interface is subject
+to change without notice.
+
+
 =head1 CONSTRUCTOR
 
-=over 8
+=over
 
 =item C<< new( -policies => \@POLICY_OBJECTS ) >>
 
@@ -77,7 +74,7 @@ Returns a reference to a new C<Perl::Critic::PolicyListing> object.
 
 =head1 METHODS
 
-=over 8
+=over
 
 =item to_string()
 
@@ -99,12 +96,12 @@ the constructor of this C<PolicyListing>.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2023 Imaginative Software Systems.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
